==> tecfy_core_package-1.0.5.tar.gz: lib/views/splash.page.dart <==
part of tecfy_core_client_package;

class SplashScreenPage extends StatefulWidget {
  @override
  _SplashScreenPageState createState() => _SplashScreenPageState();
}

class _SplashScreenPageState extends State<SplashScreenPage> {
  bool isLoading = true;
  @override
  void initState() {
    init();
    super.initState();
  }

  init() async {
    //await Future.delayed(Duration(seconds: 10000));
    InitService.init(context);
  }

  @override
  Widget build(BuildContext context) {
    return new Material(
        color: Colors.white,
        child: Stack(
          fit: StackFit.expand,
          children: <Widget>[
            Padding(
                padding: EdgeInsets.all(40.0),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: <Widget>[
                    Expanded(
                      child: Container(),
                    ),
                    TecfyCoreApp.logo == null
                        ? Container()
                        : Image(
                            image: TecfyCoreApp.logo!.image,
                            height: 250.0,
                            width: 250.0),
                    Expanded(
                      child: Container(),
                    ),
                    Center(
                        child: CircularProgressIndicator(
                            valueColor: AlwaysStoppedAnimation<Color>(
                                ThemeService.mainColor)))
                  ],
                ))
          ],
        ));
  }
}

==> tecfy_core_package-1.0.46.tar.gz: lib/views/splash.page.dart <==
part of tecfy_core_client_package;

class SplashScreenPage extends StatefulWidget {
  @override
  _SplashScreenPageState createState() => _SplashScreenPageState();
}

class _SplashScreenPageState extends State<SplashScreenPage> {
  bool _isLoading = true;
  @override
  void initState() {
    _init();
    super.initState();
  }

  _init() async {
    //await Future.delayed(Duration(seconds: 10000));
    InitService.init(context);
  }

  @override
  Widget build(BuildContext context) {
    return new Material(
        color: Colors.white,
        child: Stack(
          fit: StackFit.expand,
          children: <Widget>[
            Padding(
                padding: EdgeInsets.all(40.0),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: <Widget>[
                    Expanded(
                      child: Container(),
                    ),
                    TecfyCoreApp.logo == null
                        ? Container()
                        : Image(
                            image: TecfyCoreApp.logo!.image,
                            height: 250.0,
                            width: 250.0),
                    Expanded(
                      child: Container(),
                    ),
                    Center(
                        child: CircularProgressIndicator(
                            valueColor: AlwaysStoppedAnimation<Color>(
                                ThemeService.mainColor)))
                  ],
                ))
          ],
        ));
  }
}
